@@ -5,13 +5,18 @@ use Datahub::Factory::Sane;
 use Moo;
 use Catmandu;
 use namespace::clean;
+#use Data::Dumper qw(Dumper);
 
-has file_name     => (is => 'ro', required => 1);
+has file_name     => (is => 'ro', required => 1, isa => sub { 
+    if (!defined($_[0])) {
+        Catmandu::BadArg->throw(
+            message => 'Required argument "file_name" undefined'
+        );
+    }
+ });
 
 with 'Datahub::Factory::Fixer';
 
-# Make role; implement -> fixer (must work the same as CM::Fixer)
-
 sub _build_fixer {
     my $self = shift;
     my $fixer;
